@@ -10,7 +10,7 @@ from reportlab.pdfbase.ttfonts import TTFont
 from reportlab.pdfbase import pdfmetrics
 from reportlab.platypus.tables import Table, TableStyle
 
-from conf import _, FONT_PATH, FONT_BOLD_PATH
+from InvoiceGenerator.conf import _, FONT_PATH, FONT_BOLD_PATH
 from api import Invoice, QrCodeBuilder
 import locale
 import warnings
@@ -164,8 +164,8 @@ class SimpleInvoice(BaseInvoice):
 
         if self.invoice.client.note:
             self.pdf.setFont('DejaVu', 6)
-            text = self.pdf.beginText((LEFT + 2) * mm, (TOP - 28) * mm)
-            text.textLines(self.invoice.client.note.split("\n"))
+            text = self.pdf.beginText((LEFT + 2) * mm, (TOP - 29) * mm)
+            text.textLines(self.invoice.client.note.splitlines())
             self.pdf.drawText(text)
 
 
@@ -185,7 +185,7 @@ class SimpleInvoice(BaseInvoice):
         if self.invoice.provider.note:
             self.pdf.setFont('DejaVu', 6)
             text = self.pdf.beginText((LEFT + 2) * mm, (TOP - 23) * mm)
-            text.textLines(self.invoice.provider.note.split("\n"))
+            text.textLines(self.invoice.provider.note.splitlines())
             self.pdf.drawText(text)
 
         if self.invoice.provider.logo_filename:
